==> style-o-matic-1.1.5.tgz: package/es/components/Card/Card.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import cx from "classnames";
import { CoreComponent, getValidProps, setCorePropTypes, setCorePropDefaults, ROLE } from "../../lib";
import CardHeader from "./CardHeader";
import CardContent from "./CardContent";
import CardFooter from "./CardFooter";
import "./Card.css";

var Card = (_temp = _class = function (_CoreComponent) {
  _inherits(Card, _CoreComponent);

  function Card() {
    _classCallCheck(this, Card);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  Card.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        className = _getValidProps.className,
        striped = _getValidProps.striped,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    var classes = {
      "ui-card-striped": striped
    };

    var uiClassCore = cx(className, classes);
    delete props.className;
    return React.createElement(
      Component,
      _extends({}, props, { className: uiClassCore }),
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
          return _this2.renderChild(child, inherited);
        }
        return child;
      })
    );
  };

  return Card;
}(CoreComponent), _class.propTypes = setCorePropTypes({
  striped: "bool"
}), _class.defaultProps = setCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.CARD,
  striped: false
}), _class.Header = CardHeader, _class.Content = CardContent, _class.Footer = CardFooter, _temp);


export default Card;

==> style-o-matic-1.1.37.tgz: package/es/components/Card/Card.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import cx from "classnames";
import { CoreComponent, getValidProps, getCorePropTypes, getCorePropDefaults, ROLE } from "../../lib";
import CardHeader from "./CardHeader";
import CardContent from "./CardContent";
import CardFooter from "./CardFooter";
import "./Card.css";

var Card = (_temp = _class = function (_CoreComponent) {
  _inherits(Card, _CoreComponent);

  function Card() {
    _classCallCheck(this, Card);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  Card.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        className = _getValidProps.className,
        striped = _getValidProps.striped,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    var classes = {
      "ui-card-striped": striped
    };

    var uiClassCore = cx(className, classes);
    delete props.className;
    return React.createElement(
      Component,
      _extends({}, props, { className: uiClassCore }),
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
          return _this2.renderChild(child, inherited);
        }
        return child;
      })
    );
  };

  return Card;
}(CoreComponent), _class.propTypes = getCorePropTypes({
  striped: "bool"
}), _class.defaultProps = getCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.CARD,
  striped: false
}), _class.Header = CardHeader, _class.Content = CardContent, _class.Footer = CardFooter, _temp);


export default Card;
